@@ -1,8 +1,8 @@
 import numpy as np
-import pyfits as py
+from astropy.io import fits
 
 
-def acs_limits( x, y, filename):
+def acs_limits( x, y, filename, jwst=False):
     '''
     ;PURPOSE : TO RETURN THE INDEX OF THOSE X AND Y POSITIONS THAT
     ;          ARE WITHIN THE FIELD OF VIEW AND NOT ZERO IN THE SINGLE
@@ -16,9 +16,17 @@ def acs_limits( x, y, filename):
     ;OUTPUTS : A BOOLEAN OF THE INDEXES OF THE X AND Y POSITIONS THAT ARE IN THE FIELD
     '''
     
-    image_obj=py.open(filename)
-    imagedata = image_obj[0].data
-    header = image_obj[0].header
+    image_obj=fits.open(filename)
+    
+    if jwst:
+        extension = 1
+        orientation_header = 'PA_V3'
+    else:
+        orientation_header = 'ORIENTAT'
+        extension = 0
+        
+    imagedata = image_obj[extension].data
+    header = image_obj[extension].header
     
     zeroarr = imagedata == 0
 
@@ -42,7 +50,7 @@ def acs_limits( x, y, filename):
     
     #then all the chip positions that are in the FOV AND CHIp are value 2
    
-    return SourceArr == 2, header['ORIENTAT']
+    return SourceArr == 2, header[orientation_header]
 
 
      
