@@ -1,15 +1,19 @@
 '''
 return the HST filter of the input image
 '''
-import pyfits as fits
 
-def getHSTfilter( infile ):
+from astropy.io import fits
+
+def getHSTfilter( infile, jwst=False ):
     '''
     Take the input infile and get the filter name
     '''
 
     header = fits.open( infile )[0].header
 
+    if jwst:
+        return header['FILTER']
+
     if 'CLEAR' in header['FILTER1']:
         hst_filter = header['FILTER2']
     else:
