@@ -1,5 +1,5 @@
 from . import mmm as mmm
-import pyfits as py
+from astropy.io import fits
 import numpy as np
 import sys
 from matplotlib import pyplot as plt
@@ -16,7 +16,8 @@ def measure_moms(fits_image, sex_catalog, outfile,
                      object_catalogue=None,
                      bad_val=-99, regfile=None,
                      skymed=None, skysd=None,
-                     return_moms=True, quiet=False,**kwargs):
+                     return_moms=True, quiet=False,
+                     jwst=False, error=0.01, min_it=500, **kwargs):
                      
     '''
     ;
@@ -64,13 +65,21 @@ def measure_moms(fits_image, sex_catalog, outfile,
     ENDIF
     ;
     '''
-                     
-    img_file = py.open( fits_image )
-    img = img_file[0].data
-    imhead = img_file[0].header
-    exp_time = imhead['EXPTIME']
+    img_file = fits.open( fits_image )
+    print(fits_image)
+                   
+    if jwst:
+        extension = 1
+        expTimeName = 'XPOSURE'
+    else:
+        extension = 0
+        expTimeName = 'EXPTIME'
 
+    imhead = img_file[extension].header
+    img = img_file[extension].data
     
+    exp_time = imhead[expTimeName]
+ 
     #What is mmm?
     if (skymed is None )| \
         (skysd is None):
@@ -79,7 +88,7 @@ def measure_moms(fits_image, sex_catalog, outfile,
         print((' % f skymed and %f skysd' % (skymed,skysd)))
     
     if object_catalogue is None:
-        cat_file=py.open(sex_catalog)
+        cat_file=fits.open(sex_catalog)
         object_catalogue = cat_file[1].data
         header=cat_file[1].header
      
@@ -105,7 +114,7 @@ def measure_moms(fits_image, sex_catalog, outfile,
     if weight_image is None:
         wt_image = np.ones( img.shape)
     else:
-        wt_image = py.open( weight_image )[0].data
+        wt_image = fits.open( weight_image )[0].data
 
 
 
@@ -118,7 +127,7 @@ def measure_moms(fits_image, sex_catalog, outfile,
     
 
     if (sgm_im != 'null') & (fieldback == 1):
-        seg_file = py.open(sgm_im)
+        seg_file = fits.open(sgm_im)
         seg = seg_file[0].data
         shdr = seg_file[0].header
         '''
@@ -182,9 +191,9 @@ def measure_moms(fits_image, sex_catalog, outfile,
             
 
         if nocenter == 0:
-            while  ((np.abs(deltax) > 0.01) |  \
-              (np.abs(deltay) > 0.01)) & \
-               (count < 500) & (go_on == 1) :
+            while  ((np.abs(deltax) > error) |  \
+              (np.abs(deltay) > error)) & \
+               (count < min_it) & (go_on == 1) :
                 #These are needed for all moments
                 #Cut out a postage stamp of the image
                 begin_x = np.round(xc-cut_rad[i]-1).astype(int)
@@ -224,7 +233,7 @@ def measure_moms(fits_image, sex_catalog, outfile,
     
                 #This might be
                 g_f = np.exp(-(dist**2)/(2.*radius[i]**2))
-                weight_gal = g_f*( postage_stamp -  back[i])
+                weight_gal = g_f*( np.abs(postage_stamp -  back[i]))
                 sum_int = np.sum( weight_gal )
                 
 
@@ -274,7 +283,7 @@ def measure_moms(fits_image, sex_catalog, outfile,
                             (i,xGal[i],yGal[i],count)))
                 galaxy_moments.prob[i] += 2
                 
-            if np.sqrt( (xc-xGal[i])**2 + (yc-yGal[i])**2) > mult*radius[i]:
+            if np.sqrt( (xc-xGal[i])**2 + (yc-yGal[i])**2) > radius[i]:
                 go_on=0
                 centerprob += 1
                 if verbose:
@@ -350,7 +359,7 @@ def measure_moms(fits_image, sex_catalog, outfile,
                           
             int_moms.error.xxxy = np.sum(g_f*g_f*I_err_sq*\
                 (rel_xgrid*rel_xgrid-int_moms.xx)*\
-                (rel_ygrid*rel_xgrid-int_moms.yy))/sum_int**2
+                (rel_ygrid*rel_xgrid-int_moms.xy))/sum_int**2
                         
             int_moms.error.xyyy = np.sum(g_f*g_f*I_err_sq*\
                           (rel_xgrid*rel_xgrid-int_moms.xy)*\
@@ -375,9 +384,13 @@ def measure_moms(fits_image, sex_catalog, outfile,
     #Append some needed things
     #Can just append the RA as this is not the same as the pixel position
     #Need to find the re-centred RA
-    recentred_ra, recentred_dec = \
-      at.pix2deg( fits_image, galaxy_moments.x, galaxy_moments.y)
-
+    if jwst:
+        recentred_ra, recentred_dec = \
+              at.pix2deg( fits_image, galaxy_moments.x, galaxy_moments.y, extension=extension)
+    else:
+        recentred_ra, recentred_dec = \
+              at.pix2deg( fits_image, galaxy_moments.x, galaxy_moments.y)
+     
     galaxy_moments.ra = recentred_ra
     galaxy_moments.dec = recentred_dec
    
@@ -388,13 +401,14 @@ def measure_moms(fits_image, sex_catalog, outfile,
     galaxy_moments['skysw'][:] = skysw
     galaxy_moments['exp_time'][:] = exp_time
 
+
     galaxy_moments.write_to_fits( object_catalogue, outfile )
 
     if regfile is not None:
         galaxy_moments.fits_to_ellipse( regfile)
     
     if return_moms:
-        return py.open(outfile)[1].data
+        return fits.open(outfile)[1].data
 
 class moms( dict ):
 
@@ -475,11 +489,11 @@ class moms( dict ):
             if iColumn == 'error':
                 error_names = list(self.error.keys())
                 for iColumn_err in error_names:
-                    fits_columns.append(py.Column( name=iColumn_err+'_err',
+                    fits_columns.append(fits.Column( name=iColumn_err+'_err',
                                                    format=self.error[iColumn_err].dtype,
                                                    array=self.error[iColumn_err] ))
             else:
-                fits_columns.append(py.Column( name=iColumn, \
+                fits_columns.append(fits.Column( name=iColumn, \
                                                format=self[iColumn].dtype, \
                                                array=self[iColumn] ))
         
@@ -487,13 +501,13 @@ class moms( dict ):
             if (iCatalog in mom_names) | ('err' in iCatalog):
                 continue
             else:
-                fits_columns.append(py.Column( name=iCatalog,
+                fits_columns.append(fits.Column( name=iCatalog,
                                                    format=sex_catalog[iCatalog].dtype,
                                                    array=sex_catalog[iCatalog] ))
 
             
-        fits_table = py.BinTableHDU.from_columns( fits_columns )
-        fits_table.writeto( filename, clobber=True,output_verify='ignore' )
+        fits_table = fits.BinTableHDU.from_columns( fits_columns )
+        fits_table.writeto( filename, overwrite=True,output_verify='ignore' )
 
 
 
