@@ -5,7 +5,7 @@ from matplotlib import gridspec as gridspec
 import sys as sys
 import numpy as np
 import ipdb as pdb
-import pyfits as fits
+from astropy.io import fits
 import sklearn
 
 def star_galaxy_separation( sources, outfile, include_sat=False, redoML=False):
@@ -80,10 +80,10 @@ def star_galaxy_separation( sources, outfile, include_sat=False, redoML=False):
         new_cols = fits.ColDefs(cols)
         hduWithGalStarFlag = fits.BinTableHDU.from_columns(orig_cols + new_cols)
     
-        hduWithGalStarFlag.writeto(outfile, clobber=True)
+        hduWithGalStarFlag.writeto(outfile, overwrite=True)
     else:
         sources['galStarFlag'] = galStarObject.galStarFlag
-        fits.writeto(  outfile, sources, clobber=True )
+        fits.writeto(  outfile, sources, overwrite=True )
 
         
 #This class is where all the meat of the code is run including the interactive plotting
@@ -131,6 +131,8 @@ class galStar():
             '''
             codeDir = os.path.dirname(os.path.realpath(__file__))
             print(codeDir+'/'+rfModel)
+            if not os.path.isfile( codeDir+'/'+rfModel ):
+                raise ValueError("RF Model not found. If you have downloaded this directly from GIT then you will need to contact davidharvey1986@googlemail.com to get the latest RF model and copy it to %s." % codeDir)
             galStarFlagClassifier =  \
               pkl.load(open(codeDir+'/'+rfModel,'rb'), encoding='latin1')
 
